#!/usr/bin/python

from nilmdb.utils.printf import *

import threading

class Thread(object):
    def __init__(self, name, function, parameters):
        self.parameters = parameters
        self.start_time = None
        self.log = ''
        self._terminate = threading.Event()
        self._thread = threading.Thread(target = function,
                                        name = name,
                                        args = ( parameters,
                                                 self._terminate ))
        self._thread.daemon = True
        self._thread.start()

    def terminate(self, timeout = 60):
        self._terminate.set()
        self._thread.join(timeout = 60)

    @property
    def pid(self):
        return self._thread.ident

    @property
    def name(self):
        return self._thread.name

    @property
    def alive(self):
        return self._thread.is_alive()

class ThreadManager(object):
    def __init__(self):
        self.threads = {}

    def __iter__(self):
        return iter(self.threads.keys())

    def run(self, name, function, parameters):
        new = Thread(name, function, parameters)
        self.threads[new.pid] = new
        return new.pid
